/*
 * Linux specific functions
 *
 * Copyright (C) 2003 Olaf Kirch <okir@suse.de>
 *
 * These functions need to be re-implemented for every
 * new platform.
 */

#include "config.h"
#if defined(__linux__) && defined(HAVE_LIBUSB)

#include <sys/types.h>
#include <linux/major.h>
#include <linux/usbdevice_fs.h>
#include <sys/sysmacros.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <string.h>
#include <stdio.h>
#include <usb.h>

#include <openct/driver.h>
#include "internal.h"

/*
 * Scan all usb devices to see if there is one we support
 * This function is called at start-up because we can't be
 * sure the hotplug system notifies us of devices that were
 * attached at startup time already.
 */
int
mgr_scan_usb(void)
{
	ifd_devid_t	id;
	struct usb_bus	*bus;
	struct usb_device *dev;

	usb_init();
	usb_find_busses();
	usb_find_devices();

	id.type = IFD_DEVICE_TYPE_USB;
	id.num  = 2;
	for (bus = usb_busses; bus; bus = bus->next) {
		for (dev = bus->devices; dev; dev = dev->next) {
			const char	*driver;
			char		device[PATH_MAX];

			id.val[0] = dev->descriptor.idVendor;
			id.val[1] = dev->descriptor.idProduct;

			if (!(driver = ifd_driver_for_id(&id)))
				continue;

			snprintf(device, sizeof(device),
				"/proc/bus/usb/%s/%s",
				bus->dirname,
				dev->filename);

			mgr_spawn_ifdhandler(driver, device, -1);
		}
	}

	return 0;
}
#endif /* __linux__ && HAVE_LIBUSB */
